@@ -22,7 +22,7 @@
 
 #include "searchstore.h"
 
-#include <KDebug>
+#include <QDebug>
 #include <KService>
 #include <KServiceTypeTrader>
 #include <QThreadStorage>
@@ -59,7 +59,7 @@ QString SearchStore::property(int, const QString&)
     return QString();
 }
 
-K_GLOBAL_STATIC(QList<SearchStore*>, s_overrideSearchStores)
+Q_GLOBAL_STATIC(QList<SearchStore*>, s_overrideSearchStores)
 
 void SearchStore::overrideSearchStores(const QList<SearchStore*> &overrideSearchStores)
 {
@@ -76,12 +76,12 @@ QList<SearchStore*> SearchStore::searchStores()
     QMutexLocker lock(&mutex);
 
     if (s_overrideSearchStores && !s_overrideSearchStores->isEmpty()) {
-        kDebug() << "Overriding search stores.";
+        qDebug() << "Overriding search stores.";
         return *s_overrideSearchStores;
     }
 
     // Get all the plugins
-    KService::List plugins = KServiceTypeTrader::self()->query(QLatin1String("BalooSearchStore"));
+    KService::List plugins = KServiceTypeTrader::self()->query("BalooSearchStore");
 
     QList<Baloo::SearchStore*> stores;
     KService::List::const_iterator it;
@@ -102,8 +102,8 @@ QList<SearchStore*> SearchStore::searchStores()
             stores << st;
         }
         else {
-            kError() << "Could not create SearchStore: " << service->library();
-            kError() << pluginLoader.errorString();
+            qWarning() << "Could not create SearchStore: " << service->library();
+            qWarning() << pluginLoader.errorString();
         }
     }
 
