@@ -25,10 +25,10 @@
 #include "../basicindexingqueue.h"
 #include "../database.h"
 
-#include "qtest_kde.h"
-
+#include <QTest>
 #include <QSignalSpy>
 #include <QEventLoop>
+#include <QDebug>
 
 using namespace Baloo;
 
@@ -45,25 +45,25 @@ void BasicIndexingQueueTest::testSimpleDirectoryStructure()
     dirs << QLatin1String("home/docs/");
     dirs << QLatin1String("home/docs/1");
 
-    QScopedPointer<KTempDir> dir(Test::createTmpFilesAndFolders(dirs));
-    QString p = dir->name();
+    QScopedPointer<QTemporaryDir> dir(Test::createTmpFilesAndFolders(dirs));
 
     QStringList includeFolders;
-    includeFolders << dir->name() + QLatin1String("home");
+    includeFolders << dir->path() + "/home";
+    qDebug() << includeFolders;
 
     QStringList excludeFolders;
-    excludeFolders << dir->name() + QLatin1String("home/kde");
+    excludeFolders << dir->path() + "/home/kde";
 
     Test::writeIndexerConfig(includeFolders, excludeFolders);
 
-    KTempDir dbDir;
+    QTemporaryDir dbDir;
     Database db;
-    db.setPath(dbDir.name());
+    db.setPath(dbDir.path());
     db.init();
 
     FileIndexerConfig config;
     BasicIndexingQueue queue(&db, &config);
-    queue.enqueue(FileMapping(p + QLatin1String("home")));
+    queue.enqueue(FileMapping(dir->path() + "/home"));
 
     QSignalSpy spy(&queue, SIGNAL(newDocument(uint,Xapian::Document)));
     queue.resume();
@@ -76,4 +76,4 @@ void BasicIndexingQueueTest::testSimpleDirectoryStructure()
     QCOMPARE(spy.count(), 5);
 }
 
-QTEST_KDEMAIN_CORE(BasicIndexingQueueTest)
+QTEST_MAIN(BasicIndexingQueueTest)
