@@ -21,7 +21,7 @@
 #include "filemonitortest.h"
 #include "filemonitor.h"
 
-#include <qtest_kde.h>
+#include <QTest>
 #include <QSignalSpy>
 
 #include <QDBusConnection>
@@ -31,7 +31,7 @@ using namespace Baloo;
 
 void FileMonitorTest::test()
 {
-    QString file(QLatin1String("/tmp/t"));
+    QString file("/tmp/t");
     FileMonitor monitor;
     monitor.addFile(file);
 
