@@ -28,11 +28,11 @@
 
 #include "xapiandocument.h"
 
-#include <KDebug>
-#include <KMimeType>
+#include <QDebug>
 
 #include <QDateTime>
 #include <QTimer>
+#include <QUrl>
 
 using namespace Baloo;
 
@@ -73,7 +73,7 @@ void BasicIndexingQueue::enqueue(const FileMapping& file)
 
 void BasicIndexingQueue::enqueue(const FileMapping& file, UpdateDirFlags flags)
 {
-    kDebug() << file.url();
+    qDebug() << file.url();
     m_paths.push(qMakePair(file, flags));
     callForNextIteration();
 }
@@ -99,8 +99,7 @@ bool BasicIndexingQueue::process(FileMapping& file, UpdateDirFlags flags)
     // This mimetype may not be completely accurate, but that's okay. This is
     // just the initial phase of indexing. The second phase can try to find
     // a more accurate mimetype.
-    QString mimetype = KMimeType::findByUrl(QUrl::fromLocalFile(file.url()), 0,
-                                            true /*is Local*/, true /*Fast*/)->name();
+    QString mimetype = m_mimeDb.mimeTypeForFile(file.url(), QMimeDatabase::MatchExtension).name();
 
     bool forced = flags & ForceUpdate;
     bool recursive = flags & UpdateRecursive;
@@ -149,7 +148,7 @@ bool BasicIndexingQueue::shouldIndex(FileMapping& file, const QString& mimetype)
     }
 
     XapianDocument doc = m_db->xapianDatabase()->document(file.id());
-    const QString dtStr = doc.fetchTermStartsWith("DT_M");
+    QString dtStr = doc.fetchTermStartsWith("DT_M");
     if (dtStr.isEmpty()) {
         return true;
     }
@@ -177,7 +176,7 @@ bool BasicIndexingQueue::shouldIndexContents(const QString& dir)
 
 void BasicIndexingQueue::index(const FileMapping& file, const QString& mimetype)
 {
-    kDebug() << file.id() << file.url();
+    qDebug() << file.id() << file.url();
 
     BasicIndexingJob job(&m_db->sqlDatabase(), file, mimetype);
     if (job.index()) {
