@@ -1,6 +1,6 @@
 /*
  * This file is part of the KDE Baloo Project
- * Copyright (C) 2013  Vishesh Handa <me@vhanda.in>
+ * Copyright (C) 2013-2014  Vishesh Handa <me@vhanda.in>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -26,51 +26,43 @@
 #include "xapiandatabase.h"
 #include "../fileindexerconfig.h"
 
-#include <KCmdLineArgs>
-#include <KMimeType>
-#include <KStandardDirs>
-#include <KDebug>
+#include <QDebug>
+#include <QCoreApplication>
 
 #include <QTimer>
-#include <QtCore/QFileInfo>
+#include <QFileInfo>
 #include <QDBusMessage>
 #include <QSqlQuery>
 #include <QSqlError>
 #include <QDBusConnection>
-#include <KApplication>
+
 #include <kfilemetadata/propertyinfo.h>
 
 #include <iostream>
 
 using namespace Baloo;
 
-App::App(QObject* parent)
+App::App(const QString& path, QObject* parent)
     : QObject(parent)
+    , m_path(path)
     , m_termCount(0)
 {
-    const KCmdLineArgs* args = KCmdLineArgs::parsedArgs();
-
-    if (!args->getOption("db").isEmpty()) {
-        m_path = args->getOption("db");
-    } else {
-        m_path = KGlobal::dirs()->localxdgdatadir() + QLatin1String("baloo/file");
-    }
-
     m_db.setPath(m_path);
     if (!m_db.init(true /*sql db only*/)) {
         QTimer::singleShot(0, QCoreApplication::instance(), SLOT(quit()));
         return;
     }
-    m_db.sqlDatabase().transaction();
 
-    m_bData = args->isSet("bdata");
-    m_debugEnabled = args->isSet("debug");
+    connect(this, SIGNAL(saved()), this, SLOT(processNextUrl()), Qt::QueuedConnection);
+}
 
+void App::startProcessing(const QStringList& args)
+{
     FileIndexerConfig config;
 
-    m_results.reserve(args->count());
-    for (int i=0; i<args->count(); ++i) {
-        FileMapping mapping = FileMapping(args->arg(i).toUInt());
+    m_results.reserve(args.size());
+    Q_FOREACH (const QString& arg, args) {
+        FileMapping mapping = FileMapping(arg.toUInt());
         QString url;
 
         // arg is an id
@@ -82,14 +74,14 @@ App::App(QObject* parent)
             }
         } else {
             // arg is a url
-            url = args->url(i).toLocalFile();
+            url = QFileInfo(arg).absoluteFilePath();
         }
 
-        if (QFile::exists(url) && (m_bData || config.shouldBeIndexed(url))) {
+        if (QFile::exists(url) && config.shouldBeIndexed(url)) {
             m_urls << url;
         } else {
             // id or url was looked up, but file deleted
-            kDebug() << url << "does not exist or should not be indexed";
+            qDebug() << url << "does not exist or should not be indexed";
 
             // Try to delete it as an id:
             // it may have been deleted from the FileMapping db as well.
@@ -99,15 +91,9 @@ App::App(QObject* parent)
         }
     }
 
-    connect(this, SIGNAL(saved()), this, SLOT(processNextUrl()), Qt::QueuedConnection);
-
     QTimer::singleShot(0, this, SLOT(processNextUrl()));
 }
 
-App::~App()
-{
-}
-
 void App::processNextUrl()
 {
     if (m_urls.isEmpty()) {
@@ -121,23 +107,7 @@ void App::processNextUrl()
     }
 
     const QString url = m_urls.takeFirst();
-    QString mimetype = KMimeType::findByUrl(KUrl::fromLocalFile(url))->name();
-
-    //
-    // HACK: We only want to index plain text files which end with a .txt
-    // Also, we're ignoring txt files which are greater tha 50 Mb as we
-    // have trouble processing them
-    //
-    if (mimetype == QLatin1String("text/plain")) {
-        if (!url.endsWith(QLatin1String(".txt"))) {
-            mimetype.clear();
-        }
-
-        QFileInfo fileInfo(url);
-        if (fileInfo.size() >= 50 * 1024 * 1024 ) {
-            mimetype.clear();
-        }
-    }
+    const QString mimetype = m_mimeDb.mimeTypeForFile(url).name();
 
     FileMapping file(url);
     if (!m_bData) {
@@ -192,7 +162,6 @@ void App::processNextUrl()
                     KFileMetaData::PropertyInfo pi(prop);
                     map.insert(pi.name(), it.value());
                 }
-                qDebug() << map;
                 s << map;
             }
 
@@ -215,7 +184,7 @@ void App::saveChanges()
     m_updatedFiles.clear();
 
     XapianDatabase xapDb(m_path);
-    for (int i = 0; i<m_results.size(); ++i) {
+    for (int i = 0; i<m_results.size(); i++) {
         Result& res = m_results[i];
         res.finish();
 
@@ -230,6 +199,10 @@ void App::saveChanges()
     xapDb.commit();
     m_db.sqlDatabase().commit();
 
+    m_results.clear();
+    m_termCount = 0;
+    m_updatedFiles.clear();
+
     QDBusMessage message = QDBusMessage::createSignal(QLatin1String("/files"),
                                                       QLatin1String("org.kde"),
                                                       QLatin1String("changed"));
@@ -241,10 +214,6 @@ void App::saveChanges()
 
     QDBusConnection::sessionBus().send(message);
 
-    m_results.clear();
-    m_termCount = 0;
-    m_updatedFiles.clear();
-
     if (m_debugEnabled) {
         printDebug();
     }
@@ -269,7 +238,7 @@ void App::printDebug()
     }
 
     // Print the io usage
-    QFile file(QLatin1String("/proc/self/io"));
+    QFile file("/proc/self/io");
     file.open(QIODevice::ReadOnly | QIODevice::Text);
 
     QTextStream fs(&file);
@@ -280,25 +249,25 @@ void App::printDebug()
     while (!stream.atEnd()) {
         QString str = stream.readLine();
 
-        QString rchar(QLatin1String("rchar: "));
+        QString rchar("rchar: ");
         if (str.startsWith(rchar)) {
             ulong amt = str.mid(rchar.size()).toULong();
             qDebug() << "Read:" << amt / 1024  << "kb";
         }
 
-        QString wchar(QLatin1String("wchar: "));
+        QString wchar("wchar: ");
         if (str.startsWith(wchar)) {
             ulong amt = str.mid(wchar.size()).toULong();
             qDebug() << "Write:" << amt / 1024  << "kb";
         }
 
-        QString read(QLatin1String("read_bytes: "));
+        QString read("read_bytes: ");
         if (str.startsWith(read)) {
             ulong amt = str.mid(read.size()).toULong();
             qDebug() << "Actual Reads:" << amt / 1024  << "kb";
         }
 
-        QString write(QLatin1String("write_bytes: "));
+        QString write("write_bytes: ");
         if (str.startsWith(write)) {
             ulong amt = str.mid(write.size()).toULong();
             qDebug() << "Actual Writes:" << amt / 1024  << "kb";
