@@ -20,13 +20,14 @@
 #include "fileindexerconfig.h"
 #include "fileexcludefilters.h"
 
+#include <QUrl>
 #include <QStringList>
 #include <QDir>
 
 #include <KDirWatch>
-#include <KStandardDirs>
+#include <QStandardPaths>
 #include <KConfigGroup>
-#include <KDebug>
+#include <QDebug>
 
 
 namespace
@@ -35,7 +36,7 @@ namespace
 bool isDirHidden(QDir& dir)
 {
 #ifdef __unix__
-    return dir.absolutePath().contains(QLatin1String("/."));
+    return dir.absolutePath().contains("/.");
 #else
     if (QFileInfo(dir.path()).isHidden())
         return true;
@@ -51,7 +52,7 @@ using namespace Baloo;
 
 FileIndexerConfig::FileIndexerConfig(QObject* parent)
     : QObject(parent)
-    , m_config(QLatin1String("baloofilerc"), KConfig::SimpleConfig)
+    , m_config("baloofilerc", KConfig::SimpleConfig)
     , m_indexHidden(false)
 {
     KDirWatch* dirWatch = KDirWatch::self();
@@ -59,7 +60,7 @@ FileIndexerConfig::FileIndexerConfig(QObject* parent)
             this, SLOT(slotConfigDirty()));
     connect(dirWatch, SIGNAL(created(QString)),
             this, SLOT(slotConfigDirty()));
-    dirWatch->addFile(KStandardDirs::locateLocal("config", m_config.name()));
+    dirWatch->addFile(QStandardPaths::locate(QStandardPaths::ConfigLocation, m_config.name()));
 
     forceConfigUpdate();
 }
@@ -171,7 +172,7 @@ bool FileIndexerConfig::shouldFolderBeIndexed(const QString& path) const
 
         // check the exclude filters for all components of the path
         // after folder
-        const QStringList pathComponents = path.mid(folder.count()).split(QLatin1Char('/'), QString::SkipEmptyParts);
+        const QStringList pathComponents = path.mid(folder.count()).split('/', QString::SkipEmptyParts);
         Q_FOREACH (const QString& c, pathComponents) {
             if (!shouldFileBeIndexed(c)) {
                 return false;
@@ -204,7 +205,7 @@ bool FileIndexerConfig::folderInFolderList(const QString& path)
 
 bool FileIndexerConfig::folderInFolderList(const QString& path, QString& folder) const
 {
-    const QString p = KUrl(path).path(KUrl::RemoveTrailingSlash);
+    const QString p = QUrl(path).adjusted(QUrl::StripTrailingSlash).path();
 
     // we traverse the list backwards to catch all exclude folders
     int i = m_folderCache.count();
@@ -232,8 +233,11 @@ bool alreadyExcluded(const QList<QPair<QString, bool> >& folders, const QString&
 {
     bool included = false;
     for (int i = 0; i < folders.count(); ++i) {
-        if (f != folders[i].first &&
-                f.startsWith(KUrl(folders[i].first).path(KUrl::AddTrailingSlash))) {
+        QString path = QUrl(folders[i].first).path();
+        if (!path.endsWith('/'))
+            path.append('/');
+
+        if (f != folders[i].first && f.startsWith(path)) {
             included = folders[i].second;
         }
     }
@@ -247,7 +251,7 @@ void insertSortFolders(const QStringList& folders, bool include, QList<QPair<QSt
 {
     Q_FOREACH (const QString& f, folders) {
         int pos = 0;
-        QString path = KUrl(f).path(KUrl::RemoveTrailingSlash);
+        QString path = QUrl(f).adjusted(QUrl::StripTrailingSlash).path();
         while (result.count() > pos &&
                 result[pos].first < path)
             ++pos;
@@ -322,7 +326,7 @@ bool FileIndexerConfig::buildFolderCache()
     QSet<QString> includeSet = includeFoldersPlain.toSet();
     QSet<QString> excludeSet = excludeFoldersPlain.toSet();
 
-    Entry& generalEntry = m_entries[ QLatin1String("General") ];
+    Entry& generalEntry = m_entries[ "General" ];
     fillIncludeFolderChanges(generalEntry, includeSet, &includeAdded, &includeRemoved);
     fillExcludeFolderChanges(generalEntry, excludeSet, &excludeAdded, &excludeRemoved);
 
@@ -334,7 +338,7 @@ bool FileIndexerConfig::buildFolderCache()
     //
     QStringList groupList = m_config.groupList();
     Q_FOREACH (const QString& groupName, groupList) {
-        if (!groupName.startsWith(QLatin1String("Device-")))
+        if (!groupName.startsWith("Device-"))
             continue;
 
         KConfigGroup group = m_config.group(groupName);
