@@ -26,7 +26,7 @@
 #include "util.h"
 #include "database.h"
 
-#include <KDebug>
+#include <QDebug>
 
 using namespace Baloo;
 
@@ -46,11 +46,6 @@ void FileIndexingQueue::fillQueue()
     if (m_fileQueue.size() >= m_maxSize)
         return;
 
-    // We do not want to refill the queue when a job is going on
-    // this will result in unnecessary duplicates
-    if (m_indexJob)
-        return;
-
     try {
         Xapian::Database* db = m_db->xapianDatabase()->db();
         Xapian::Enquire enquire(*db);
@@ -58,7 +53,7 @@ void FileIndexingQueue::fillQueue()
 
         Xapian::MSet mset = enquire.get_mset(0, m_maxSize - m_fileQueue.size());
         Xapian::MSetIterator it = mset.begin();
-        for (; it != mset.end(); ++it) {
+        for (; it != mset.end(); it++) {
             m_fileQueue << *it;
         }
     }
@@ -80,7 +75,7 @@ void FileIndexingQueue::processNextIteration()
     QVector<uint> files;
     files.reserve(m_batchSize);
 
-    for (int i=0; i<m_batchSize && m_fileQueue.size(); ++i) {
+    for (int i=0; i<m_batchSize && m_fileQueue.size(); i++) {
         files << m_fileQueue.pop();
     }
 
@@ -94,15 +89,15 @@ void FileIndexingQueue::processNextIteration()
 
 void FileIndexingQueue::slotFinishedIndexingFile(KJob* job)
 {
-    Q_ASSERT(job == m_indexJob);
-    m_indexJob = 0;
-
     // The process would have modified the db
     m_db->xapianDatabase()->db()->reopen();
     if (m_fileQueue.isEmpty()) {
         fillQueue();
     }
     finishIteration();
+
+    Q_ASSERT(job == m_indexJob);
+    m_indexJob = 0;
 }
 
 void FileIndexingQueue::slotIndexingFailed(uint id)
