@@ -24,13 +24,13 @@
 #include <Solid/StorageAccess>
 #include <Solid/StorageDrive>
 
-#include <KIcon>
-#include <KDebug>
-#include <KFileDialog>
+#include <QIcon>
+#include <QDebug>
+#include <QFileDialog>
 
 #include <QDir>
 #include <QTimer>
-#include <KUrl>
+#include <QUrl>
 #include <KLocalizedString>
 #include <QBoxLayout>
 #include <QSpacerItem>
@@ -54,12 +54,12 @@ FolderSelectionWidget::FolderSelectionWidget(QWidget* parent, Qt::WindowFlags f)
     hLayout->addItem(spacer);
 
     m_addButton = new QPushButton(this);
-    m_addButton->setIcon(KIcon(QLatin1String("list-add")));
+    m_addButton->setIcon(QIcon::fromTheme("list-add"));
     connect(m_addButton, SIGNAL(clicked(bool)),
             this, SLOT(slotAddButtonClicked()));
 
     m_removeButton = new QPushButton(this);
-    m_removeButton->setIcon(KIcon(QLatin1String("list-remove")));
+    m_removeButton->setIcon(QIcon::fromTheme("list-remove"));
     m_removeButton->setEnabled(false);
     connect(m_removeButton, SIGNAL(clicked(bool)),
             this, SLOT(slotRemoveButtonClicked()));
@@ -134,7 +134,7 @@ void FolderSelectionWidget::setFolders(QStringList includeDirs, QStringList excl
         item->setData(Qt::DisplayRole, display);
         item->setData(Qt::WhatsThisRole, url);
         item->setData(UrlRole, url);
-        item->setData(Qt::DecorationRole, KIcon(iconName(url)));
+        item->setData(Qt::DecorationRole, QIcon(iconName(url)));
         item->setToolTip(makeHomePretty(url));
 
         m_listWidget->addItem(item);
@@ -196,7 +196,7 @@ QString FolderSelectionWidget::fetchMountPoint(const QString& url) const
 
 void FolderSelectionWidget::slotAddButtonClicked()
 {
-    QString url = KFileDialog::getExistingDirectory(KUrl(), this, i18n("Select the folder which should be excluded"));
+    QString url = QFileDialog::getExistingDirectory(this, i18n("Select the folder which should be excluded"));
     if (url.isEmpty()) {
         return;
     }
@@ -222,7 +222,7 @@ void FolderSelectionWidget::slotAddButtonClicked()
         QString existingUrl = item->data(UrlRole).toString();
 
         if (existingUrl == url) {
-            QString name = KUrl(QUrl::fromLocalFile(url)).fileName();
+            QString name = QUrl::fromLocalFile(url).fileName();
             showMessage(i18n("Folder %1 is already excluded").arg(name));
 
             deleteList << item;
@@ -243,7 +243,7 @@ void FolderSelectionWidget::slotAddButtonClicked()
                 url = existingUrl;
                 deleteList << item;
 
-                QString name = KUrl(QUrl::fromLocalFile(url)).fileName();
+                QString name = QUrl::fromLocalFile(url).fileName();
                 showMessage(i18n("Folder's parent %1 is already excluded").arg(name));
             }
         }
@@ -256,7 +256,7 @@ void FolderSelectionWidget::slotAddButtonClicked()
     item->setData(Qt::DisplayRole, display);
     item->setData(Qt::WhatsThisRole, url);
     item->setData(UrlRole, url);
-    item->setData(Qt::DecorationRole, KIcon(iconName(url)));
+    item->setData(Qt::DecorationRole, QIcon::fromTheme(iconName(url)));
     item->setToolTip(makeHomePretty(url));
 
     m_listWidget->addItem(item);
@@ -293,7 +293,7 @@ QString FolderSelectionWidget::getFolderDisplayName(const QString& url) const
     QString name = url;
 
     // Check Home Dir
-    QString homePath = QDir::homePath() + QLatin1Char('/');
+    QString homePath = QDir::homePath() + '/';
     if (url == homePath) {
         return QDir(homePath).dirName();
     }
@@ -305,13 +305,13 @@ QString FolderSelectionWidget::getFolderDisplayName(const QString& url) const
         // Check Mount allMountPointsExcluded
         Q_FOREACH (QString mountPoint, m_mountPoints) {
             if (url.startsWith(mountPoint)) {
-                name = QLatin1Char('[') + QDir(mountPoint).dirName() + QLatin1String("]/") + url.mid(mountPoint.length());
+                name = "[" + QDir(mountPoint).dirName() + "]/" + url.mid(mountPoint.length());
                 break;
             }
         }
     }
 
-    if (name.endsWith(QLatin1Char('/'))) {
+    if (name.endsWith('/')) {
         name = name.mid(0, name.size() - 1);
     }
     return name;
@@ -319,7 +319,7 @@ QString FolderSelectionWidget::getFolderDisplayName(const QString& url) const
 
 bool FolderSelectionWidget::shouldShowMountPoint(const QString& mountPoint)
 {
-    if (mountPoint == QLatin1String("/"))
+    if (mountPoint == "/")
         return false;
 
     if (mountPoint.startsWith(QLatin1String("/boot")))
