@@ -26,9 +26,12 @@
 #include <KAboutData>
 #include <KSharedConfig>
 #include <KDirWatch>
-#include <KDebug>
-#include <KStandardDirs>
+#include <QDebug>
+#include <QStandardPaths>
+#include <KLocalizedString>
+#include <KConfigGroup>
 
+#include <QStyle>
 #include <QPushButton>
 #include <QDir>
 #include <QProcess>
@@ -37,7 +40,7 @@
 #include <QDBusPendingCall>
 
 K_PLUGIN_FACTORY(BalooConfigModuleFactory, registerPlugin<Baloo::ServerConfigModule>();)
-K_EXPORT_PLUGIN(BalooConfigModuleFactory("kcm_baloofile", "kcm_baloofile"))
+K_EXPORT_PLUGIN(BalooConfigModuleFactory("kcm_baloofile"))
 
 
 namespace
@@ -52,28 +55,25 @@ QStringList defaultFolders()
 using namespace Baloo;
 
 ServerConfigModule::ServerConfigModule(QWidget* parent, const QVariantList& args)
-    : KCModule(BalooConfigModuleFactory::componentData(), parent, args)
+    : KCModule(parent, args)
 {
     KAboutData* about = new KAboutData(
-        "kcm_baloofile", "kcm_baloofile", ki18n("Configure Desktop Search"),
-        KDE_VERSION_STRING, KLocalizedString(), KAboutData::License_GPL,
-        ki18n("Copyright 2007-2010 Sebastian Trüg"));
-    about->addAuthor(ki18n("Sebastian Trüg"), KLocalizedString(), "trueg@kde.org");
-    about->addAuthor(ki18n("Vishesh Handa"), KLocalizedString(), "vhanda@kde.org");
+        "kcm_baloofile", "kcm_baloofile", i18n("Configure Desktop Search"),
+        "0.1", QString(), KAboutData::License_GPL,
+        i18n("Copyright 2007-2010 Sebastian Trüg"));
+    about->addAuthor(i18n("Sebastian Trüg"), QString(), "trueg@kde.org");
+    about->addAuthor(i18n("Vishesh Handa"), QString(), "vhanda@kde.org");
     setAboutData(about);
     setButtons(Help | Apply | Default);
 
     setupUi(this);
 
-    const QPixmap pixmap = KIcon(QLatin1String("baloo")).pixmap(IconSize(KIconLoader::Desktop));
+    int pixelSize = style()->pixelMetric(QStyle::PM_LargeIconSize);
+    QPixmap pixmap = QIcon::fromTheme("baloo").pixmap(QSize(pixelSize, pixelSize));
     m_pixmapLabel->setPixmap(pixmap);
 
     connect(m_folderSelectionWidget, SIGNAL(changed()),
             this, SLOT(changed()));
-    connect(m_folderSelectionWidget, SIGNAL(changed()),
-            this, SLOT(folderSelectionChanged()));
-    connect(m_enableCheckbox, SIGNAL(stateChanged(int)),
-            this, SLOT(changed()));
 }
 
 
@@ -85,13 +85,9 @@ ServerConfigModule::~ServerConfigModule()
 void ServerConfigModule::load()
 {
     // File indexer settings
-    KConfig config(QLatin1String("baloofilerc"));
+    KConfig config("baloofilerc");
     KConfigGroup group = config.group("General");
 
-    KConfigGroup basicSettings = config.group("Basic Settings");
-    m_previouslyEnabled = basicSettings.readEntry("Indexing-Enabled", true);
-    m_enableCheckbox->setChecked(m_previouslyEnabled);
-
     QStringList includeFolders = group.readPathEntry("folders", defaultFolders());
     QStringList excludeFolders = group.readPathEntry("exclude folders", QStringList());
     m_folderSelectionWidget->setFolders(includeFolders, excludeFolders);
@@ -107,28 +103,19 @@ void ServerConfigModule::save()
     QStringList excludeFolders = m_folderSelectionWidget->excludeFolders();
 
     // Change the settings
-    KConfig config(QLatin1String("baloofilerc"));
+    KConfig config("baloofilerc");
     KConfigGroup basicSettings = config.group("Basic Settings");
 
-    bool mountPointsEx = m_folderSelectionWidget->allMountPointsExcluded();
-
-    bool enabled = m_enableCheckbox->isChecked();
-    if (mountPointsEx)
-        enabled = false;
-
-    basicSettings.writeEntry("Indexing-Enabled", enabled);
+    bool indexingEnabled = !m_folderSelectionWidget->allMountPointsExcluded();
+    basicSettings.writeEntry("Indexing-Enabled", indexingEnabled);
 
     // 2.2 Update normals paths
     config.group("General").writePathEntry("folders", includeFolders);
     config.group("General").writePathEntry("exclude folders", excludeFolders);
 
-    if (m_previouslyEnabled != enabled) {
-        config.group("General").deleteEntry("first run");
-    }
-
     // Start Baloo
-    if (enabled) {
-        const QString exe = KStandardDirs::findExe(QLatin1String("baloo_file"));
+    if (indexingEnabled) {
+        const QString exe = QStandardPaths::findExecutable(QLatin1String("baloo_file"));
         QProcess::startDetached(exe);
     }
     else {
@@ -141,7 +128,7 @@ void ServerConfigModule::save()
     }
 
     // Start cleaner
-    const QString exe = KStandardDirs::findExe(QLatin1String("baloo_file_cleaner"));
+    const QString exe = QStandardPaths::findExecutable(QLatin1String("baloo_file_cleaner"));
     QProcess::startDetached(exe);
 
     // all values saved -> no changes
@@ -154,10 +141,4 @@ void ServerConfigModule::defaults()
     m_folderSelectionWidget->setFolders(defaultFolders(), QStringList());
 }
 
-void ServerConfigModule::folderSelectionChanged()
-{
-    const bool disabled = m_folderSelectionWidget->allMountPointsExcluded();
-    m_enableCheckbox->setChecked(!disabled);
-}
-
 #include "kcm.moc"
