@@ -39,9 +39,7 @@ public Q_SLOTS:
     void save();
     void defaults();
 
-    void folderSelectionChanged();
 private:
-    bool m_previouslyEnabled;
 };
 }
 
