@@ -26,12 +26,15 @@
 #include "filemapping.h"
 #include "file.h"
 
-#include "qtest_kde.h"
 #include <QSqlQuery>
-#include <KTempDir>
-#include <KDebug>
+#include <QDebug>
+#include <QTest>
+#include <QTemporaryFile>
+#include <QTemporaryDir>
+
+#include <QJsonDocument>
+#include <QJsonObject>
 
-#include <qjson/serializer.h>
 #include <xapian.h>
 
 #include <kfilemetadata/properties.h>
@@ -47,19 +50,21 @@ void FileFetchJobTest::init()
 
     // Clear the sqlite db
     QSqlDatabase sqlDb = fileMappingDb();
-    sqlDb.exec(QLatin1String("delete from files"));
+    sqlDb.exec("delete from files");
 }
 
 void FileFetchJobTest::testXapianData()
 {
-    QJson::Serializer serializer;
-
     using namespace KFileMetaData;
     PropertyMap map;
-    map.insert(Property::Album, QLatin1String("value1"));
-    map.insert(Property::Artist, QLatin1String("value2"));
+    map.insert(Property::Album, "value1");
+    map.insert(Property::Artist, "value2");
 
-    QByteArray json = serializer.serialize(toVariantMap(map));
+    QJsonObject jo = QJsonObject::fromVariantMap(toVariantMap(map));
+    QJsonDocument jdoc;
+    jdoc.setObject(jo);
+
+    QByteArray json = jdoc.toJson();
     QVERIFY(!json.isEmpty());
 
     Xapian::Document doc;
@@ -97,7 +102,7 @@ void FileFetchJobTest::testExtendedAttributes()
     QString fileName = tempFile.fileName();
     XattrDetector detector;
     if (!detector.isSupported(fileName)) {
-        kWarning() << "Xattr not supported on this filesystem";
+        qWarning() << "Xattr not supported on this filesystem";
         return;
     }
 
@@ -109,12 +114,12 @@ void FileFetchJobTest::testExtendedAttributes()
     QVERIFY(baloo_setxattr(fileName, QLatin1String("user.baloo.rating"), rat) != -1);
 
     QStringList tags;
-    tags << QLatin1String("TagA") << QLatin1String("TagB");
+    tags << "TagA" << "TagB";
 
-    QString tagStr = tags.join(QLatin1String(","));
+    QString tagStr = tags.join(",");
     QVERIFY(baloo_setxattr(fileName, QLatin1String("user.xdg.tags"), tagStr) != -1);
 
-    const QString userComment(QLatin1String("UserComment"));
+    const QString userComment("UserComment");
     QVERIFY(baloo_setxattr(fileName, QLatin1String("user.xdg.comment"), userComment) != -1);
 
     FileFetchJob* job = new FileFetchJob(tempFile.fileName());
@@ -128,20 +133,17 @@ void FileFetchJobTest::testExtendedAttributes()
 
 void FileFetchJobTest::testFolder()
 {
-    QTemporaryFile f(QLatin1String(BUILDDIR "testFolder.XXXXXX"));
-    f.open();
-
     // We use the same prefix as the tmpfile
-    KTempDir tmpDir(f.fileName().mid(0, f.fileName().lastIndexOf(QLatin1Char('/')) + 1));
-    QString fileName = tmpDir.name();
+    QTemporaryDir tmpDir;
+    QString fileName = tmpDir.path();
 
     XattrDetector detector;
     if (!detector.isSupported(fileName)) {
-        kWarning() << "Xattr not supported on this filesystem";
+        qWarning() << "Xattr not supported on this filesystem";
         return;
     }
 
-    FileMapping fileMap(tmpDir.name());
+    FileMapping fileMap(fileName);
     QSqlDatabase sqlDb = fileMappingDb();
     QVERIFY(fileMap.create(sqlDb));
 
@@ -149,15 +151,15 @@ void FileFetchJobTest::testFolder()
     QVERIFY(baloo_setxattr(fileName, QLatin1String("user.baloo.rating"), rat) != -1);
 
     QStringList tags;
-    tags << QLatin1String("TagA") << QLatin1String("TagB");
+    tags << "TagA" << "TagB";
 
-    QString tagStr = tags.join(QLatin1String(","));
+    QString tagStr = tags.join(",");
     QVERIFY(baloo_setxattr(fileName, QLatin1String("user.xdg.tags"), tagStr) != -1);
 
-    const QString userComment(QLatin1String("UserComment"));
+    const QString userComment("UserComment");
     QVERIFY(baloo_setxattr(fileName, QLatin1String("user.xdg.comment"), userComment) != -1);
 
-    FileFetchJob* job = new FileFetchJob(tmpDir.name());
+    FileFetchJob* job = new FileFetchJob(fileName);
     job->exec();
     File file = job->file();
 
@@ -166,4 +168,4 @@ void FileFetchJobTest::testFolder()
     QCOMPARE(file.userComment(), userComment);
 }
 
-QTEST_KDEMAIN_CORE(FileFetchJobTest)
+QTEST_MAIN(FileFetchJobTest)
