@@ -25,7 +25,7 @@
 #include <QFile>
 #include <QString>
 
-#if defined(Q_OS_LINUX) || defined(__GLIBC__)
+#if defined(Q_OS_LINUX)
 #include <sys/types.h>
 #include <sys/xattr.h>
 #elif defined(Q_OS_MAC)
@@ -45,13 +45,13 @@ inline ssize_t baloo_getxattr(const QString& path, const QString& name, QString*
     const char* attributeName = n.constData();
 
     // First get the size of the data we are going to get to reserve the right amount of space.
-#if defined(Q_OS_LINUX) || (defined(__GLIBC__) && !defined(__stub_getxattr))
+#if defined(Q_OS_LINUX)
     const ssize_t size = getxattr(encodedPath, attributeName, NULL, 0);
 #elif defined(Q_OS_MAC)
     const ssize_t size = getxattr(encodedPath, attributeName, NULL, 0, 0, 0);
 #elif defined(Q_OS_FREEBSD) || defined(Q_OS_NETBSD)
     const ssize_t size = extattr_get_file(encodedPath, EXTATTR_NAMESPACE_USER, attributeName, NULL, 0);
-#else
+#elif defined(Q_OS_WIN)
     const ssize_t size = 0;
 #endif
 
@@ -64,13 +64,13 @@ inline ssize_t baloo_getxattr(const QString& path, const QString& name, QString*
 
     QByteArray data(size, Qt::Uninitialized);
 
-#if defined(Q_OS_LINUX) || (defined(__GLIBC__) && !defined(__stub_getxattr))
+#if defined(Q_OS_LINUX)
     const ssize_t r = getxattr(encodedPath, attributeName, data.data(), size);
 #elif defined(Q_OS_MAC)
     const ssize_t r = getxattr(encodedPath, attributeName, data.data(), size, 0, 0);
 #elif defined(Q_OS_FREEBSD) || defined(Q_OS_NETBSD)
     const ssize_t r = extattr_get_file(encodedPath, EXTATTR_NAMESPACE_USER, attributeName, data.data(), size);
-#else
+#elif defined(Q_OS_WIN)
     const ssize_t r = 0;
 #endif
 
@@ -91,37 +91,16 @@ inline int baloo_setxattr(const QString& path, const QString& name, const QStrin
 
     const size_t valueSize = v.size();
 
-#if defined(Q_OS_LINUX) || (defined(__GLIBC__) && !defined(__stub_setxattr))
+#if defined(Q_OS_LINUX)
     return setxattr(encodedPath, attributeName, attributeValue, valueSize, 0);
 #elif defined(Q_OS_MAC)
     return setxattr(encodedPath, attributeName, attributeValue, valueSize, 0, 0);
 #elif defined(Q_OS_FREEBSD) || defined(Q_OS_NETBSD)
     const ssize_t count = extattr_set_file(encodedPath, EXTATTR_NAMESPACE_USER, attributeName, attributeValue, valueSize);
     return count == -1 ? -1 : 0;
-#else
+#elif defined(Q_OS_WIN)
     return -1;
 #endif
 }
 
-
-inline int baloo_removexattr(const QString& path, const QString& name)
-{
-    const QByteArray p = QFile::encodeName(path);
-    const char* encodedPath = p.constData();
-
-    const QByteArray n = name.toUtf8();
-    const char* attributeName = n.constData();
-
-    #if defined(Q_OS_LINUX) || (defined(__GLIBC__) && !defined(__stub_removexattr))
-        return removexattr(encodedPath, attributeName);
-    #elif defined(Q_OS_MAC)
-        return removexattr(encodedPath, attributeName, XATTR_NOFOLLOW );
-    #elif defined(Q_OS_FREEBSD) || defined(Q_OS_NETBSD)
-        return removexattr (encodedPath, attributeName);
-    #else
-        return -1;
-    #endif
-
-}
-
 #endif // BALOO_XATTR_P_H
