@@ -31,10 +31,12 @@
 #include <QTimer>
 #include <QFile>
 
-#include <xapian.h>
-#include <qjson/parser.h>
+#include <QJsonDocument>
+#include <QJsonObject>
 
-#include <KDebug>
+#include <xapian.h>
+
+#include <QDebug>
 
 #include <sys/types.h>
 
@@ -88,14 +90,14 @@ void FileFetchJob::doStart()
         const QString& url = file.url();
         if (url.size() && !QFile::exists(url)) {
             setError(Error_FileDoesNotExist);
-            setErrorText(QLatin1String("File ") + url + QLatin1String(" does not exist"));
+            setErrorText("File " + url + " does not exist");
             emitResult();
             return;
         }
 
         if (file.id().size() && !file.id().startsWith("file")) {
             setError(Error_InvalidId);
-            setErrorText(QLatin1String("Invalid Id ") + QString::fromUtf8(file.id()));
+            setErrorText("Invalid Id " + QString::fromUtf8(file.id()));
             emitResult();
             return;
         }
@@ -105,7 +107,7 @@ void FileFetchJob::doStart()
         fileMap.setUrl(file.url());
 
         if (!fileMap.fetch(fileMappingDb())) {
-            kDebug() << "No file index information found" << url;
+            qDebug() << "No file index information found" << url;
             // TODO: Send file for indexing!!
 
             d->fetchUserMetadata(file);
@@ -119,25 +121,23 @@ void FileFetchJob::doStart()
         file.setUrl(fileMap.url());
 
         // Fetch data from Xapian
+        Xapian::Database db(fileIndexDbPath());
         try {
-            Xapian::Database db(fileIndexDbPath());
             Xapian::Document doc = db.get_document(id);
 
             std::string docData = doc.get_data();
             const QByteArray arr(docData.c_str(), docData.length());
 
-            QJson::Parser parser;
-            QVariantMap varMap = parser.parse(arr).toMap();
+            QJsonDocument jdoc = QJsonDocument::fromJson(arr);
+            const QVariantMap varMap = jdoc.object().toVariantMap();
+
             file.d->propertyMap = KFileMetaData::toPropertyMap(varMap);
         }
         catch (const Xapian::DocNotFoundError&){
             // Send file for indexing to baloo_file
         }
         catch (const Xapian::InvalidArgumentError& err) {
-            kError() << err.get_msg().c_str();
-        }
-        catch (const Xapian::Error& err) {
-            kError() << "Xapian error of type" << err.get_type() << ":" << err.get_msg().c_str();
+            qWarning() << err.get_msg().c_str();
         }
 
         d->fetchUserMetadata(file);
@@ -154,7 +154,7 @@ void FileFetchJob::Private::fetchUserMetadata(File& file)
     QString comment = customFileMetaData(url, QLatin1String("user.xdg.comment"));
 
     file.setRating(rating.toInt());
-    file.setTags(tags.split(QLatin1Char(','), QString::SkipEmptyParts));
+    file.setTags(tags.split(',', QString::SkipEmptyParts));
     file.setUserComment(comment);
 }
 
