@@ -21,7 +21,7 @@
  */
 
 #include "filemapping.h"
-#include <KDebug>
+#include <QDebug>
 
 #include <QSqlQuery>
 #include <QSqlError>
@@ -123,7 +123,7 @@ bool FileMapping::create(QSqlDatabase db)
     query.addBindValue(m_url);
 
     if (!query.exec()) {
-        kError() << query.lastError().text();
+        qWarning() << query.lastError().text();
         return false;
     }
 
@@ -139,18 +139,18 @@ bool FileMapping::remove(QSqlDatabase db)
     QSqlQuery query(db);
 
     if (!m_url.isEmpty()) {
-        query.prepare(QLatin1String("delete from files where url = ?"));
+        query.prepare("delete from files where url = ?");
         query.addBindValue(m_url);
         if (!query.exec()) {
-            kError() << query.lastError().text();
+            qWarning() << query.lastError().text();
             return false;
         }
     }
     else {
-        query.prepare(QLatin1String("delete from files where id = ?"));
+        query.prepare("delete from files where id = ?");
         query.addBindValue(m_id);
         if (!query.exec()) {
-            kError() << query.lastError().text();
+            qWarning() << query.lastError().text();
             return false;
         }
     }
