@@ -28,7 +28,7 @@
 #include "xapiandatabase.h"
 #include "xapiandocument.h"
 
-#include <KDebug>
+#include <QDebug>
 
 #include <QTimer>
 #include <QFile>
@@ -117,7 +117,7 @@ void FileModifyJob::doStart()
 
         if (!QFile::exists(fileMap.url())) {
             setError(Error_FileDoesNotExist);
-            setErrorText(QString::fromLatin1("Does not exist %1").arg(fileMap.url()));
+            setErrorText("Does not exist " + fileMap.url());
             emitResult();
             return;
         }
@@ -131,7 +131,7 @@ void FileModifyJob::doStart()
         }
 
         if (d->tagsSet) {
-            const QString tags = d->tags.join(QLatin1String(","));
+            QString tags = d->tags.join(",");
             setCustomFileMetaData(furl, QLatin1String("user.xdg.tags"), tags);
         }
 
@@ -150,16 +150,16 @@ void FileModifyJob::doStart()
 
         const int rating = d->rating;
         if (rating > 0) {
-            doc.addBoolTerm(rating, QLatin1String("R"));
+            doc.addBoolTerm(rating, "R");
         }
 
         Q_FOREACH (const QString& tag, d->tags) {
-            doc.indexText(tag, QLatin1String("TA"));
-            doc.addBoolTerm(tag, QLatin1String("TAG-"));
+            doc.indexText(tag, "TA");
+            doc.addBoolTerm(tag, "TAG-");
         }
 
         if (!d->comment.isEmpty()) {
-            doc.indexText(d->comment, QLatin1String("C"));
+            doc.indexText(d->comment, "C");
         }
 
         d->m_db->replaceDocument(fileMap.id(), doc.doc());
