@@ -20,7 +20,7 @@
 
 #include "taglistjob.h"
 #include "db.h"
-#include <KDebug>
+#include <QDebug>
 
 #include <xapian.h>
 #include <QStringList>
@@ -50,10 +50,10 @@ void TagListJob::start()
         Xapian::TermIterator it = xapianDb.allterms_begin("TAG-");
         Xapian::TermIterator end = xapianDb.allterms_end("TAG-");
 
-        for (; it != end; ++it ) {
+        for (; it != end; it++ ) {
             std::string str = *it;
-            const QString tag = QString::fromUtf8(str.c_str(), str.length());
-            if (tag.startsWith(QLatin1String("TAG-"))) {
+            QString tag = QString::fromUtf8(str.c_str(), str.length());
+            if (tag.startsWith("TAG-")) {
                 d->tags << tag.mid(4);
             }
         }
