@@ -20,16 +20,13 @@
  *
  */
 
-#include <KComponentData>
 #include <KAboutData>
-#include <KStandardDirs>
-#include <KCmdLineArgs>
-#include <KUniqueApplication>
 #include <KCrash>
+#include <KLocalizedString>
 
 #include <KConfig>
 #include <KConfigGroup>
-#include <KDebug>
+#include <QDebug>
 #include <iostream>
 
 #include "filewatch.h"
@@ -39,6 +36,7 @@
 #include "priority.h"
 
 #include <QDBusConnection>
+#include <QApplication>
 
 int main(int argc, char** argv)
 {
@@ -46,14 +44,17 @@ int main(int argc, char** argv)
     lowerSchedulingPriority();
     lowerPriority();
 
-    KAboutData aboutData("baloo_file", "baloo_file", ki18n("Baloo File"), "0.1",
-                         ki18n("An application to handle file metadata"),
-                         KAboutData::License_GPL_V2);
+    KAboutData aboutData("baloo_file", "baloo_file", i18n("Baloo File"), "0.1",
+                         i18n("An application to handle file metadata"),
+                         KAboutData::License_LGPL_V2);
+    aboutData.addAuthor(i18n("Vishesh Handa"), i18n("Maintainer"), "me@vhanda.in", "http://vhanda.in");
 
-    KCmdLineArgs::init(argc, argv, &aboutData);
+    KAboutData::setApplicationData(aboutData);
 
-    KUniqueApplication app(true);
-    app.disableSessionManagement();
+    QApplication app(argc, argv);
+    app.setQuitOnLastWindowClosed(false);
+    //KUniqueApplication app(true);
+    //app.disableSessionManagement();
 
     KConfig config("baloofilerc");
     KConfigGroup group = config.group("Basic Settings");
@@ -66,14 +67,14 @@ int main(int argc, char** argv)
 
 
     if (!QDBusConnection::sessionBus().registerService("org.kde.baloo.file")) {
-        kError() << "Failed to register via dbus. Another instance is running";
+        qWarning() << "Failed to register via dbus. Another instance is running";
         return 1;
     }
 
     // Crash Handling
     KCrash::setFlags(KCrash::AutoRestart);
 
-    const QString path = KGlobal::dirs()->localxdgdatadir() + "baloo/file/";
+    const QString path = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + "/baloo/file/";
 
     Database db;
     db.setPath(path);
