@@ -22,9 +22,10 @@
 
 #include <QTime>
 #include <QTimer>
+#include <QUrl>
 
-#include <KStandardDirs>
-#include <KMimeType>
+#include <QStandardPaths>
+#include <QMimeDatabase>
 
 using namespace Baloo;
 
@@ -49,14 +50,14 @@ void FileIndexer::start()
 void FileIndexer::doStart()
 {
     // Get the mimetype - used for stats later
-    m_mimeType = KMimeType::findByUrl(QUrl::fromLocalFile(m_url))->name();
+    m_mimeType = QMimeDatabase().mimeTypeForFile(m_url, QMimeDatabase::MatchExtension).name();
 
     // setup the external process which does the actual indexing
-    const QString exe = KStandardDirs::findExe(QLatin1String("baloo_file_extractor"));
+    const QString exe = QStandardPaths::findExecutable(QLatin1String("baloo_file_extractor"));
 
     QStringList args;
     args << QString::number(m_id);
-    args << QLatin1String("--db") << m_customPath;
+    args << "--db" << m_customPath;
 
     m_process = new QProcess(this);
     connect(m_process, SIGNAL(finished(int,QProcess::ExitStatus)),
@@ -68,7 +69,7 @@ void FileIndexer::doStart()
     m_process->start(exe, args);
 }
 
-void FileIndexer::slotIndexedFile(int returnCode, QProcess::ExitStatus status)
+void FileIndexer::slotIndexedFile(int, QProcess::ExitStatus)
 {
     m_elapsed = m_timer.elapsed();
 
