@@ -22,13 +22,13 @@
 
 #include "kio_tags.h"
 
-#include <KUrl>
+#include <QUrl>
 #include <kio/global.h>
 #include <klocale.h>
 #include <kio/job.h>
 #include <KUser>
-#include <KDebug>
-#include <KLocale>
+#include <QDebug>
+#include <KLocalizedString>
 #include <kio/netaccess.h>
 #include <KComponentData>
 
@@ -78,9 +78,9 @@ KIO::UDSEntry createUDSEntryForTag(const QString& tag)
 }
 }
 
-void TagsProtocol::listDir(const KUrl& url)
+void TagsProtocol::listDir(const QUrl& url)
 {
-    kDebug() << url;
+    qDebug() << url;
 
     QString tag;
     QString fileUrl;
@@ -91,7 +91,7 @@ void TagsProtocol::listDir(const KUrl& url)
         return;
 
     case RootUrl: {
-        kDebug() << "Root Url";
+        qDebug() << "Root Url";
 
         TagListJob* job = new TagListJob();
         job->exec();
@@ -107,12 +107,12 @@ void TagsProtocol::listDir(const KUrl& url)
 
     case TagUrl: {
         Query q;
-        q.addType(QLatin1String("File"));
-        q.setTerm(Term(QLatin1String("tag"), tag));
+        q.addType("File");
+        q.setTerm(Term("tag", tag));
 
         ResultIterator it = q.exec();
         while (it.next()) {
-            const KUrl url = it.url();
+            const QUrl url = it.url();
             const QString fileUrl = url.toLocalFile();
 
             // Somehow stat the file
@@ -142,15 +142,15 @@ void TagsProtocol::listDir(const KUrl& url)
     }
 
     case FileUrl:
-        kDebug() << "File URL : " << fileUrl;
+        qDebug() << "File URL : " << fileUrl;
         ForwardingSlaveBase::listDir(QUrl::fromLocalFile(fileUrl));
         return;
     }
 }
 
-void TagsProtocol::stat(const KUrl& url)
+void TagsProtocol::stat(const QUrl& url)
 {
-    kDebug() << url;
+    qDebug() << url;
 
     QString tag;
     QString fileUrl;
@@ -190,9 +190,9 @@ void TagsProtocol::stat(const KUrl& url)
     }
 }
 
-void TagsProtocol::copy(const KUrl& src, const KUrl& dest, int permissions, KIO::JobFlags flags)
+void TagsProtocol::copy(const QUrl& src, const QUrl& dest, int permissions, KIO::JobFlags flags)
 {
-    kDebug() << src << dest;
+    qDebug() << src << dest;
 
     if (src.scheme() != QLatin1String("file")) {
         error(KIO::ERR_UNSUPPORTED_ACTION, src.prettyUrl());
@@ -227,9 +227,9 @@ void TagsProtocol::copy(const KUrl& src, const KUrl& dest, int permissions, KIO:
 }
 
 
-void TagsProtocol::get(const KUrl& url)
+void TagsProtocol::get(const QUrl& url)
 {
-    kDebug() << url;
+    qDebug() << url;
 
     QString tag;
     QString fileUrl;
@@ -251,7 +251,7 @@ void TagsProtocol::get(const KUrl& url)
 }
 
 
-void TagsProtocol::put(const KUrl& url, int permissions, KIO::JobFlags flags)
+void TagsProtocol::put(const QUrl& url, int permissions, KIO::JobFlags flags)
 {
     Q_UNUSED(permissions);
     Q_UNUSED(flags);
@@ -261,9 +261,9 @@ void TagsProtocol::put(const KUrl& url, int permissions, KIO::JobFlags flags)
 }
 
 
-void TagsProtocol::rename(const KUrl& src, const KUrl& dest, KIO::JobFlags flags)
+void TagsProtocol::rename(const QUrl& src, const QUrl& dest, KIO::JobFlags flags)
 {
-    kDebug() << src << dest;
+    qDebug() << src << dest;
     if (src.isLocalFile()) {
         error(KIO::ERR_CANNOT_DELETE_ORIGINAL, src.prettyUrl());
         return;
@@ -286,7 +286,7 @@ void TagsProtocol::rename(const KUrl& src, const KUrl& dest, KIO::JobFlags flags
         // Yes, this is weird, but it is required
         // It is required cause the dest url is of the form tags:/tag/file_url_with_new_filename
         // So we extract the new fileUrl from the 'src', and apply the new file to the dest
-        KUrl destUrl(fileUrl);
+        QUrl destUrl(fileUrl);
         destUrl.setFileName(dest.fileName());
 
         ForwardingSlaveBase::rename(fileUrl, destUrl, flags);
@@ -295,7 +295,7 @@ void TagsProtocol::rename(const KUrl& src, const KUrl& dest, KIO::JobFlags flags
     }
 }
 
-void TagsProtocol::del(const KUrl& url, bool isfile)
+void TagsProtocol::del(const QUrl& url, bool isfile)
 {
     Q_UNUSED(isfile);
     /*
@@ -321,14 +321,14 @@ void TagsProtocol::del(const KUrl& url, bool isfile)
     }
 
     case FileUrl: {
-        kDebug() << "Removing file url : " << fileUrl;
+        qDebug() << "Removing file url : " << fileUrl;
         // FIXME: FUCK!!!!!!
         TagRelation rel(tag, );
         TagRelationRemoveJob* job = new TagRelationRemoveJob(T);
         job->exec();
 
         if (job->error()) {
-            kError() << job->errorString();
+            qWarning() << job->errorString();
             error(KIO::ERR_CANNOT_DELETE, job->errorString());
         } else {
             finished();
@@ -339,9 +339,9 @@ void TagsProtocol::del(const KUrl& url, bool isfile)
 }
 
 
-void TagsProtocol::mimetype(const KUrl& url)
+void TagsProtocol::mimetype(const QUrl& url)
 {
-    kDebug() << url;
+    qDebug() << url;
 
     QString tag;
     QString fileUrl;
@@ -353,7 +353,7 @@ void TagsProtocol::mimetype(const KUrl& url)
 
     case RootUrl:
     case TagUrl:
-        mimeType(QLatin1String("inode/directory"));
+        mimeType("inode/directory");
         finished();
         return;
 
@@ -365,7 +365,7 @@ void TagsProtocol::mimetype(const KUrl& url)
 
 // The ForwardingSlaveBase functions are always called with a file:// url
 // In this case we just set the newUrl = url
-bool TagsProtocol::rewriteUrl(const KUrl& url, KUrl& newURL)
+bool TagsProtocol::rewriteUrl(const QUrl& url, QUrl& newURL)
 {
     if (url.scheme() != QLatin1String("file"))
         return false;
@@ -385,7 +385,7 @@ QString TagsProtocol::encodeFileUrl(const QString& url)
 }
 
 
-TagsProtocol::ParseResult TagsProtocol::parseUrl(const KUrl& url, QString& tag, QString& fileUrl, bool ignoreErrors)
+TagsProtocol::ParseResult TagsProtocol::parseUrl(const QUrl& url, QString& tag, QString& fileUrl, bool ignoreErrors)
 {
     QString path = url.path();
     if (path.isEmpty() || path == QLatin1String("/"))
@@ -404,7 +404,7 @@ TagsProtocol::ParseResult TagsProtocol::parseUrl(const KUrl& url, QString& tag,
     }
     else {
         tag = names[0];
-        QString fileName = url.fileName(KUrl::ObeyTrailingSlash);
+        QString fileName = url.fileName(QUrl::ObeyTrailingSlash);
         fileUrl = decodeFileUrl(fileName);
 
         return FileUrl;
@@ -421,7 +421,7 @@ extern "C"
         QCoreApplication app(argc, argv);
 
         if (argc != 4) {
-            kError() << "Usage: kio_tags protocol domain-socket1 domain-socket2";
+            qWarning() << "Usage: kio_tags protocol domain-socket1 domain-socket2";
             exit(-1);
         }
 
