@@ -24,13 +24,13 @@
 #include "query.h"
 #include "resultiterator.h"
 
-#include <KUrl>
+#include <QUrl>
 #include <kio/global.h>
 #include <klocale.h>
 #include <kio/job.h>
 #include <KUser>
-#include <KDebug>
-#include <KLocale>
+#include <QDebug>
+#include <KLocalizedString>
 #include <kio/netaccess.h>
 #include <KComponentData>
 #include <KCalendarSystem>
@@ -75,14 +75,14 @@ KIO::UDSEntry createMonthUDSEntry(int month, int year)
 
 KIO::UDSEntry createDayUDSEntry(const QDate& date)
 {
-    KIO::UDSEntry uds = createFolderUDSEntry(date.toString(QLatin1String("yyyy-MM-dd")),
-                        KGlobal::locale()->formatDate(date, KLocale::FancyLongDate),
+    KIO::UDSEntry uds = createFolderUDSEntry(date.toString("yyyy-MM-dd"),
+                        KGlobal::locale()->formatDate(date, KLocalizedString::FancyLongDate),
                         date);
 
     return uds;
 }
 
-KIO::UDSEntry createFileUDSEntry(const KUrl& fileUrl)
+KIO::UDSEntry createFileUDSEntry(const QUrl& fileUrl)
 {
     KIO::UDSEntry uds;
     // Code from kdelibs/kioslaves/file.cpp
@@ -120,7 +120,7 @@ TimelineProtocol::~TimelineProtocol()
 }
 
 
-void TimelineProtocol::listDir(const KUrl& url)
+void TimelineProtocol::listDir(const QUrl& url)
 {
     switch (parseTimelineUrl(url, &m_date, &m_filename)) {
     case RootFolder:
@@ -145,7 +145,7 @@ void TimelineProtocol::listDir(const KUrl& url)
 
     case DayFolder: {
         Query query;
-        query.addType(QLatin1String("File"));
+        query.addType("File");
         query.setDateFilter(m_date.year(), m_date.month(), m_date.day());
 
         ResultIterator it = query.exec();
@@ -166,7 +166,7 @@ void TimelineProtocol::listDir(const KUrl& url)
 }
 
 
-void TimelineProtocol::mimetype(const KUrl& url)
+void TimelineProtocol::mimetype(const QUrl& url)
 {
     switch (parseTimelineUrl(url, &m_date, &m_filename)) {
     case RootFolder:
@@ -183,7 +183,7 @@ void TimelineProtocol::mimetype(const KUrl& url)
 }
 
 
-void TimelineProtocol::stat(const KUrl& url)
+void TimelineProtocol::stat(const QUrl& url)
 {
     switch (parseTimelineUrl(url, &m_date, &m_filename)) {
     case RootFolder: {
@@ -224,7 +224,7 @@ void TimelineProtocol::stat(const KUrl& url)
 void TimelineProtocol::listDays(int month, int year)
 {
     const int days = KGlobal::locale()->calendar()->daysInMonth(year, month);
-    for (int day = 1; day <= days; ++day) {
+    for (int day = 1; day <= days; day++) {
         QDate date(year, month, day);
 
         if (date <= QDate::currentDate() && filesInDate(date)) {
@@ -236,7 +236,7 @@ void TimelineProtocol::listDays(int month, int year)
 bool TimelineProtocol::filesInDate(const QDate& date)
 {
     Query query;
-    query.addType(QLatin1String("File"));
+    query.addType("File");
     query.setLimit(1);
     query.setDateFilter(date.year(), date.month(), date.day());
 
@@ -248,7 +248,7 @@ bool TimelineProtocol::filesInDate(const QDate& date)
 void TimelineProtocol::listThisYearsMonths()
 {
     Query query;
-    query.addType(QLatin1String("File"));
+    query.addType("File");
     query.setLimit(1);
 
     int year = QDate::currentDate().year();
@@ -271,17 +271,17 @@ extern "C"
         KComponentData("kio_timeline");
         QCoreApplication app(argc, argv);
 
-        kDebug() << "Starting timeline slave " << getpid();
+        qDebug() << "Starting timeline slave " << getpid();
 
         if (argc != 4) {
-            kError() << "Usage: kio_timeline protocol domain-socket1 domain-socket2";
+            qWarning() << "Usage: kio_timeline protocol domain-socket1 domain-socket2";
             exit(-1);
         }
 
         Baloo::TimelineProtocol slave(argv[2], argv[3]);
         slave.dispatchLoop();
 
-        kDebug() << "Timeline slave Done";
+        qDebug() << "Timeline slave Done";
 
         return 0;
     }
