@@ -26,8 +26,8 @@
 #include "abstractindexer.h"
 
 #include <KMime/Message>
-#include <Akonadi/Collection>
-#include <Akonadi/Item>
+#include <Collection>
+#include <Item>
 
 #include <xapian.h>
 
@@ -48,7 +48,6 @@ public:
 
     void remove(const Akonadi::Item &item);
     void remove(const Akonadi::Collection &collection);
-    void move(const Akonadi::Item::Id &itemId, const Akonadi::Entity::Id &from, const Akonadi::Entity::Id &to);
 private:
     void processPart(KMime::Content *content, KMime::Content *mainContent);
     void process(const KMime::Message::Ptr &msg);
