@@ -26,14 +26,14 @@
 #include "term.h"
 #include "resultiterator.h"
 
-#include <akonadi/searchquery.h>
+#include <searchquery.h>
 
-#include <KDebug>
+#include <QDebug>
 #include <Akonadi/KMime/MessageFlags>
 #include <KDateTime>
-#include <KABC/Addressee>
-#include <KABC/ContactGroup>
 #include <QtPlugin>
+#include <QStringList>
+#include <QDateTime>
 
 static Baloo::Term::Operation mapRelation(Akonadi::SearchTerm::Relation relation) {
     if (relation == Akonadi::SearchTerm::RelAnd){
@@ -82,142 +82,114 @@ Baloo::Term recursiveEmailTermMapping(const Akonadi::SearchTerm &term)
         }
         return t;
     } else {
-        kDebug() << term.key() << term.value();
+        qDebug() << term.key() << term.value();
         const Akonadi::EmailSearchTerm::EmailSearchField field = Akonadi::EmailSearchTerm::fromKey(term.key());
         switch (field) {
             case Akonadi::EmailSearchTerm::Message: {
                 Baloo::Term s(Baloo::Term::Or);
                 s.setNegation(term.isNegated());
-                s.addSubTerm(Baloo::Term(QLatin1String("body"), term.value(), mapComparator(term.condition())));
-                s.addSubTerm(Baloo::Term(QLatin1String("headers"), term.value(), mapComparator(term.condition())));
+                s.addSubTerm(Baloo::Term("body", term.value(), mapComparator(term.condition())));
+                s.addSubTerm(Baloo::Term("headers", term.value(), mapComparator(term.condition())));
                 return s;
             }
             case Akonadi::EmailSearchTerm::Body:
-                return getTerm(term, QLatin1String("body"));
+                return getTerm(term, "body");
             case Akonadi::EmailSearchTerm::Headers:
-                return getTerm(term, QLatin1String("headers"));
+                return getTerm(term, "headers");
             case Akonadi::EmailSearchTerm::ByteSize:
-                return getTerm(term, QLatin1String("size"));
+                return getTerm(term, "size");
             case Akonadi::EmailSearchTerm::HeaderDate: {
-                Baloo::Term s(QLatin1String("date"), QString::number(term.value().toDateTime().toTime_t()), mapComparator(term.condition()));
+                Baloo::Term s("date", QString::number(term.value().toDateTime().toTime_t()), mapComparator(term.condition()));
                 s.setNegation(term.isNegated());
                 return s;
             }
             case Akonadi::EmailSearchTerm::HeaderOnlyDate: {
-                Baloo::Term s(QLatin1String("onlydate"), QString::number(term.value().toDate().toJulianDay()), mapComparator(term.condition()));
+                Baloo::Term s("onlydate", QString::number(term.value().toDate().toJulianDay()), mapComparator(term.condition()));
                 s.setNegation(term.isNegated());
                 return s;
             }
             case Akonadi::EmailSearchTerm::Subject:
-                return getTerm(term, QLatin1String("subject"));
+                return getTerm(term, "subject");
             case Akonadi::EmailSearchTerm::HeaderFrom:
-                return getTerm(term, QLatin1String("from"));
+                return getTerm(term, "from");
             case Akonadi::EmailSearchTerm::HeaderTo:
-                return getTerm(term, QLatin1String("to"));
+                return getTerm(term, "to");
             case Akonadi::EmailSearchTerm::HeaderCC:
-                return getTerm(term, QLatin1String("cc"));
+                return getTerm(term, "cc");
             case Akonadi::EmailSearchTerm::HeaderBCC:
-                return getTerm(term, QLatin1String("bcc"));
+                return getTerm(term, "bcc");
             case Akonadi::EmailSearchTerm::MessageStatus:
                 if (term.value().toString() == QString::fromLatin1(Akonadi::MessageFlags::Flagged)) {
-                    return Baloo::Term(QLatin1String("isimportant"), !term.isNegated());
+                    return Baloo::Term("isimportant", !term.isNegated());
                 }
                 if (term.value().toString() == QString::fromLatin1(Akonadi::MessageFlags::ToAct)) {
-                    return Baloo::Term(QLatin1String("istoact"), !term.isNegated());
+                    return Baloo::Term("istoact", !term.isNegated());
                 }
                 if (term.value().toString() == QString::fromLatin1(Akonadi::MessageFlags::Watched)) {
-                    return Baloo::Term(QLatin1String("iswatched"), !term.isNegated());
+                    return Baloo::Term("iswatched", !term.isNegated());
                 }
                 if (term.value().toString() == QString::fromLatin1(Akonadi::MessageFlags::Deleted)) {
-                    return Baloo::Term(QLatin1String("isdeleted"), !term.isNegated());
+                    return Baloo::Term("isdeleted", !term.isNegated());
                 }
                 if (term.value().toString() == QString::fromLatin1(Akonadi::MessageFlags::Spam)) {
-                    return Baloo::Term(QLatin1String("isspam"), !term.isNegated());
+                    return Baloo::Term("isspam", !term.isNegated());
                 }
                 if (term.value().toString() == QString::fromLatin1(Akonadi::MessageFlags::Replied)) {
-                    return Baloo::Term(QLatin1String("isreplied"), !term.isNegated());
+                    return Baloo::Term("isreplied", !term.isNegated());
                 }
                 if (term.value().toString() == QString::fromLatin1(Akonadi::MessageFlags::Ignored)) {
-                    return Baloo::Term(QLatin1String("isignored"), !term.isNegated());
+                    return Baloo::Term("isignored", !term.isNegated());
                 }
                 if (term.value().toString() == QString::fromLatin1(Akonadi::MessageFlags::Forwarded)) {
-                    return Baloo::Term(QLatin1String("isforwarded"), !term.isNegated());
+                    return Baloo::Term("isforwarded", !term.isNegated());
                 }
                 if (term.value().toString() == QString::fromLatin1(Akonadi::MessageFlags::Sent)) {
-                    return Baloo::Term(QLatin1String("issent"), !term.isNegated());
+                    return Baloo::Term("issent", !term.isNegated());
                 }
                 if (term.value().toString() == QString::fromLatin1(Akonadi::MessageFlags::Queued)) {
-                    return Baloo::Term(QLatin1String("isqueued"), !term.isNegated());
+                    return Baloo::Term("isqueued", !term.isNegated());
                 }
                 if (term.value().toString() == QString::fromLatin1(Akonadi::MessageFlags::Ham)) {
-                    return Baloo::Term(QLatin1String("isham"), !term.isNegated());
+                    return Baloo::Term("isham", !term.isNegated());
                 }
                 if (term.value().toString() == QString::fromLatin1(Akonadi::MessageFlags::Seen)) {
-                    return Baloo::Term(QLatin1String("isread"), !term.isNegated());
+                    return Baloo::Term("isread", !term.isNegated());
                 }
                 if (term.value().toString() == QString::fromLatin1(Akonadi::MessageFlags::HasAttachment)) {
-                    return Baloo::Term(QLatin1String("hasattachment"), !term.isNegated());
+                    return Baloo::Term("hasattachment", !term.isNegated());
                 }
                 if (term.value().toString() == QString::fromLatin1(Akonadi::MessageFlags::Encrypted)) {
-                    return Baloo::Term(QLatin1String("isencrypted"), !term.isNegated());
+                    return Baloo::Term("isencrypted", !term.isNegated());
                 }
                 if (term.value().toString() == QString::fromLatin1(Akonadi::MessageFlags::HasInvitation)) {
-                    return Baloo::Term(QLatin1String("hasinvitation"), !term.isNegated());
+                    return Baloo::Term("hasinvitation", !term.isNegated());
                 }
                 break;
             case Akonadi::EmailSearchTerm::MessageTag:
                 //search directly in akonadi? or index tags.
                 break;
             case Akonadi::EmailSearchTerm::HeaderReplyTo:
-                return getTerm(term, QLatin1String("replyto"));
+                return getTerm(term, "replyto");
             case Akonadi::EmailSearchTerm::HeaderOrganization:
-                return getTerm(term, QLatin1String("organization"));
+                return getTerm(term, "organization");
             case Akonadi::EmailSearchTerm::HeaderListId:
-                return getTerm(term, QLatin1String("listid"));
+                return getTerm(term, "listid");
             case Akonadi::EmailSearchTerm::HeaderResentFrom:
-                return getTerm(term, QLatin1String("resentfrom"));
+                return getTerm(term, "resentfrom");
             case Akonadi::EmailSearchTerm::HeaderXLoop:
-                return getTerm(term, QLatin1String("xloop"));
+                return getTerm(term, "xloop");
             case Akonadi::EmailSearchTerm::HeaderXMailingList:
-                return getTerm(term, QLatin1String("xmailinglist"));
+                return getTerm(term, "xmailinglist");
             case Akonadi::EmailSearchTerm::HeaderXSpamFlag:
-                return getTerm(term, QLatin1String("xspamflag"));
+                return getTerm(term, "xspamflag");
             case Akonadi::EmailSearchTerm::Unknown:
             default:
-                kWarning() << "unknown term " << term.key();
+                qWarning() << "unknown term " << term.key();
         }
     }
     return Baloo::Term();
 }
 
-Baloo::Term recursiveCalendarTermMapping(const Akonadi::SearchTerm &term)
-{
-    if (!term.subTerms().isEmpty()) {
-        Baloo::Term t(mapRelation(term.relation()));
-        Q_FOREACH (const Akonadi::SearchTerm &subterm, term.subTerms()) {
-            const Baloo::Term newTerm = recursiveCalendarTermMapping(subterm);
-            if (newTerm.isValid()) {
-                t.addSubTerm(newTerm);
-            }
-        }
-        return t;
-    } else {
-        kDebug() << term.key() << term.value();
-#if 0
-        const Akonadi::EmailSearchTerm::EmailSearchField field = Akonadi::EmailSearchTerm::fromKey(term.key());
-        switch (field) {
-        case Akonadi::EmailSearchTerm::Subject:
-            return getTerm(term, QLatin1String("subject");
-        case Akonadi::EmailSearchTerm::Body:
-            return getTerm(term, QLatin1String("body");
-        default:
-            kWarning() << "unknown term " << term.key();
-        }
-#endif
-    }
-    return Baloo::Term();
-}
-
 Baloo::Term recursiveNoteTermMapping(const Akonadi::SearchTerm &term)
 {
     if (!term.subTerms().isEmpty()) {
@@ -230,15 +202,15 @@ Baloo::Term recursiveNoteTermMapping(const Akonadi::SearchTerm &term)
         }
         return t;
     } else {
-        kDebug() << term.key() << term.value();
+        qDebug() << term.key() << term.value();
         const Akonadi::EmailSearchTerm::EmailSearchField field = Akonadi::EmailSearchTerm::fromKey(term.key());
         switch (field) {
         case Akonadi::EmailSearchTerm::Subject:
-            return getTerm(term, QLatin1String("subject"));
+            return getTerm(term, "subject");
         case Akonadi::EmailSearchTerm::Body:
-            return getTerm(term, QLatin1String("body"));
+            return getTerm(term, "body");
         default:
-            kWarning() << "unknown term " << term.key();
+            qWarning() << "unknown term " << term.key();
         }
     }
     return Baloo::Term();
@@ -256,20 +228,20 @@ Baloo::Term recursiveContactTermMapping(const Akonadi::SearchTerm &term)
         }
         return t;
     } else {
-        kDebug() << term.key() << term.value();
+        qDebug() << term.key() << term.value();
         const Akonadi::ContactSearchTerm::ContactSearchField field = Akonadi::ContactSearchTerm::fromKey(term.key());
         switch (field) {
             case Akonadi::ContactSearchTerm::Name:
-                return getTerm(term, QLatin1String("name"));
+                return getTerm(term, "name");
             case Akonadi::ContactSearchTerm::Email:
-                return getTerm(term, QLatin1String("email"));
+                return getTerm(term, "email");
             case Akonadi::ContactSearchTerm::Nickname:
-                return getTerm(term, QLatin1String("nick"));
+                return getTerm(term, "nick");
             case Akonadi::ContactSearchTerm::Uid:
-                return getTerm(term, QLatin1String("uid"));
+                return getTerm(term, "uid");
             case Akonadi::ContactSearchTerm::Unknown:
             default:
-                kWarning() << "unknown term " << term.key();
+                qWarning() << "unknown term " << term.key();
         }
     }
     return Baloo::Term();
@@ -279,39 +251,34 @@ QSet<qint64> SearchPlugin::search(const QString &akonadiQuery, const QList<qint6
 {
     const Akonadi::SearchQuery searchQuery = Akonadi::SearchQuery::fromJSON(akonadiQuery.toLatin1());
     if (searchQuery.isNull()) {
-        kWarning() << "invalid query " << akonadiQuery;
+        qWarning() << "invalid query " << akonadiQuery;
         return QSet<qint64>();
     }
     const Akonadi::SearchTerm term = searchQuery.term();
 
     Baloo::Query query;
     if (term.subTerms().isEmpty()) {
-        kWarning() << "empty query";
+        qWarning() << "empty query";
         return QSet<qint64>();
     }
 
     Baloo::Term t;
-
-    if (mimeTypes.contains(QLatin1String("message/rfc822"))) {
-        kDebug() << "mail query";
-        query.setType(QLatin1String("Email"));
+    if (mimeTypes.contains("message/rfc822")) {
+        qDebug() << "mail query";
+        query.setType("Email");
         t = recursiveEmailTermMapping(term);
-    } else if (mimeTypes.contains(KABC::Addressee::mimeType()) || mimeTypes.contains(KABC::ContactGroup::mimeType())) {
-        query.setType(QLatin1String("Contact"));
+    } else if (mimeTypes.contains("text/directory")) {
+        query.setType("Contact");
         t = recursiveContactTermMapping(term);
     } else if (mimeTypes.contains(QLatin1String("text/x-vnd.akonadi.note"))) {
-        query.setType(QLatin1String("Note"));
+        query.setType("Note");
         t = recursiveNoteTermMapping(term);
-    } else if (mimeTypes.contains(QLatin1String("application/x-vnd.akonadi.calendar.event")) ||
-               mimeTypes.contains(QLatin1String("application/x-vnd.akonadi.calendar.todo")) ||
-               mimeTypes.contains(QLatin1String("application/x-vnd.akonadi.calendar.journal")) ||
-               mimeTypes.contains(QLatin1String("application/x-vnd.akonadi.calendar.freebusy"))) {
-        query.setType(QLatin1String("Calendar"));
-        t = recursiveCalendarTermMapping(term);
+    } else if (mimeTypes.contains("...")) {
+        query.setType("ContactGroups");
+        //TODO contactgroup queries
     }
-
     if (t.subTerms().isEmpty()) {
-        kWarning() << "no terms added";
+        qWarning() << "no terms added";
         return QSet<qint64>();
     }
 
@@ -324,7 +291,7 @@ QSet<qint64> SearchPlugin::search(const QString &akonadiQuery, const QList<qint6
         Baloo::Term parentTerm(Baloo::Term::And);
         Baloo::Term collectionTerm(Baloo::Term::Or);
         Q_FOREACH (const qint64 col, collections) {
-            collectionTerm.addSubTerm(Baloo::Term(QLatin1String("collection"), QString::number(col)));
+            collectionTerm.addSubTerm(Baloo::Term("collection", QString::number(col)));
         }
         parentTerm.addSubTerm(collectionTerm);
         parentTerm.addSubTerm(t);
@@ -335,15 +302,16 @@ QSet<qint64> SearchPlugin::search(const QString &akonadiQuery, const QList<qint6
     }
 
     QSet<qint64> resultSet;
-    kDebug() << query.toJSON();
+    qDebug() << query.toJSON();
     Baloo::ResultIterator iter = query.exec();
     while (iter.next()) {
         const QByteArray id = iter.id();
         const int fid = Baloo::deserialize("akonadi", id);
         resultSet << fid;
     }
-    kDebug() << "Got" << resultSet.count() << "results";
+    qDebug() << "Got" << resultSet.count() << "results";
     return resultSet;
 }
 
-Q_EXPORT_PLUGIN2(akonadi_baloo_searchplugin, SearchPlugin)
+//QT5
+//Q_EXPORT_PLUGIN2(akonadi_baloo_searchplugin, SearchPlugin)
