@@ -22,11 +22,12 @@
 
 #include "query.h"
 #include "contactquery.h"
+#include <qjsondocument.h>
 
 #include <QVariant>
-#include <KDebug>
+#include <QDebug>
 
-#include <qjson/parser.h>
+#include <QJsonDocument>
 
 using namespace Baloo::PIM;
 
@@ -42,35 +43,34 @@ Query::~Query()
 
 Query* Query::fromJSON(const QByteArray& json)
 {
-    QJson::Parser parser;
-    bool ok = false;
-
-    QVariantMap result = parser.parse(json, &ok).toMap();
-    if (!ok) {
-        kError() << "Could not parse json query";
+    QJsonParseError error;
+    QJsonDocument doc = QJsonDocument::fromJson(json, &error);
+    if (doc.isNull()) {
+        qWarning() << "Could not parse json query" << error.errorString();
         return 0;
     }
 
-    const QString type = result[QLatin1String("type")].toString().toLower();
-    if (type != QLatin1String("contact")) {
-        kError() << "Can only handle contact queries";
+    QVariantMap result = doc.toVariant().toMap();
+    const QString type = result["type"].toString().toLower();
+    if (type != "contact") {
+        qWarning() << "Can only handle contact queries";
         return 0;
     }
 
     ContactQuery* cq = new ContactQuery();
-    cq->matchName(result[QLatin1String("name")].toString());
-    cq->matchNickname(result[QLatin1String("nick")].toString());
-    cq->matchEmail(result[QLatin1String("email")].toString());
-    cq->matchUID(result[QLatin1String("uid")].toString());
-    cq->match(result[QLatin1String("$")].toString());
+    cq->matchName(result["name"].toString());
+    cq->matchNickname(result["nick"].toString());
+    cq->matchEmail(result["email"].toString());
+    cq->matchUID(result["uid"].toString());
+    cq->match(result["$"].toString());
 
-    const QString criteria = result[QLatin1String("matchCriteria")].toString().toLower();
-    if (criteria == QLatin1String("exact"))
+    const QString criteria = result["matchCriteria"].toString().toLower();
+    if (criteria == "exact")
         cq->setMatchCriteria(ContactQuery::ExactMatch);
-    else if (criteria == QLatin1String("startswith"))
+    else if (criteria == "startswith")
         cq->setMatchCriteria(ContactQuery::StartsWithMatch);
 
-    cq->setLimit(result[QLatin1String("limit")].toInt());
+    cq->setLimit(result["limit"].toInt());
 
     return cq;
 }
