@@ -25,7 +25,7 @@
 
 #include <QCoreApplication>
 #include <QTimer>
-#include <KDebug>
+#include <QDebug>
 
 #include <Akonadi/ItemFetchJob>
 #include <Akonadi/ItemFetchScope>
@@ -51,9 +51,9 @@ int main(int argc, char** argv)
     App app(argc, argv);
 
     if (argc != 2) {
-        kError() << "Proper args required";
+        qWarning() << "Proper args required";
     }
-    app.m_query = QString::fromUtf8(argv[1]);
+    app.m_query = argv[1];
 
     return app.exec();
 }
@@ -75,7 +75,7 @@ void App::main()
     while (it.next()) {
         m_akonadiIds << it.id();
     }
-    kDebug() << "Got" << m_akonadiIds.size() << "items";
+    qDebug() << "Got" << m_akonadiIds.size() << "items";
 
     if (m_akonadiIds.isEmpty()) {
         quit();
@@ -98,7 +98,7 @@ void App::itemsReceived(const Akonadi::Item::List& itemList)
     Q_FOREACH (const Akonadi::Item& item, itemList) {
         KMime::Message::Ptr message = item.payload<KMime::Message::Ptr>();
         KDateTime date = message->date()->dateTime().toUtc();
-        kDebug() << date.toString(KDateTime::ISODate) << message->subject()->asUnicodeString();
+        qDebug() << date.toString(KDateTime::ISODate) << message->subject()->asUnicodeString();
     }
 }
 
