@@ -22,8 +22,7 @@
 
 #include "contactsearchstore.h"
 
-#include <KStandardDirs>
-#include <KDebug>
+#include <QDebug>
 
 using namespace Baloo;
 
@@ -35,10 +34,6 @@ ContactSearchStore::ContactSearchStore(QObject* parent)
     m_prefix.insert("email", ""); // Email currently doesn't map to anything
     m_prefix.insert("collection", "C");
 
-
-    m_valueProperties.insert("birthday", 0);
-    m_valueProperties.insert("anniversary", 1);
-
     setDbPath(findDatabase("contacts"));
 }
 
@@ -47,4 +42,4 @@ QStringList ContactSearchStore::types()
     return QStringList() << "Akonadi" << "Contact";
 }
 
-BALOO_EXPORT_SEARCHSTORE(Baloo::ContactSearchStore, "baloo_contactsearchstore")
+#include "contactsearchstore.moc"
