@@ -19,16 +19,15 @@
 */
 
 #include <QCoreApplication>
-#include <QHash>
+#include <QCommandLineParser>
+#include <QCommandLineOption>
 #include <QUrl>
 #include <QFile>
+#include <QFileInfo>
+#include <QTextStream>
 
-#include <KCmdLineArgs>
 #include <KAboutData>
-#include <KLocale>
-#include <KComponentData>
-#include <KDebug>
-#include <KUrl>
+#include <KLocalizedString>
 
 #include "file.h"
 #include "filefetchjob.h"
@@ -48,40 +47,38 @@ int main(int argc, char* argv[])
 {
     KAboutData aboutData("balooshow",
                          "balooshow",
-                         ki18n("Baloo Show"),
+                         i18n("Baloo Show"),
                          "0.1",
-                         ki18n("The Baloo data Viewer - A debugging tool"),
+                         i18n("The Baloo data Viewer - A debugging tool"),
                          KAboutData::License_GPL,
-                         ki18n("(c) 2012, Vishesh Handa"),
-                         KLocalizedString(),
-                         "http://kde.org");
-    aboutData.addAuthor(ki18n("Vishesh Handa"), ki18n("Maintainer"), "me@vhanda.in");
-
-    KCmdLineArgs::init(argc, argv, &aboutData);
-
-    KCmdLineOptions options;
-    options.add("+resource", ki18n("The file URL"));
-    KCmdLineArgs::addCmdLineOptions(options);
-
-    KCmdLineArgs* args = KCmdLineArgs::parsedArgs();
+                         i18n("(c) 2012, Vishesh Handa"));
+    aboutData.addAuthor(i18n("Vishesh Handa"), i18n("Maintainer"), "me@vhanda.in");
 
+    KAboutData::setApplicationData(aboutData);
     QCoreApplication app(argc, argv);
-    KComponentData comp(aboutData);
 
-    if (args->count() == 0)
-        KCmdLineArgs::usage();
+    QCommandLineParser parser;
+    parser.addPositionalArgument("files", "The file urls");
+    parser.process(app);
+
+    QStringList args = parser.positionalArguments();
+
+    if (args.isEmpty()) {
+        parser.showHelp(1);
+    }
+
+    QTextStream err(stdout);
 
     //
     // The Resource Uri
     //
-    QVector<QString> urls;
-    for (int i = 0; i < args->count(); ++i) {
-        const QString url = args->url(i).toLocalFile();
+    QStringList urls;
+    Q_FOREACH (const QString& arg, args) {
+        const QString url = QFileInfo(arg).absoluteFilePath();
         if (QFile::exists(url)) {
             urls.append(url);
-        }
-        else {
-            urls.append(QLatin1String("file:") + args->arg(i));
+        } else {
+            urls.append(QLatin1String("file:") + arg);
         }
     }
 
@@ -91,7 +88,7 @@ int main(int argc, char* argv[])
 
     Q_FOREACH (const QString& url, urls) {
         Baloo::File ifile;
-        if (url.startsWith(QLatin1String("file:"))) {
+        if (url.startsWith("file:")) {
             ifile.setId(url.toUtf8());
         }
         else {
@@ -105,7 +102,7 @@ int main(int argc, char* argv[])
 
         if (fid && !file.url().isEmpty()) {
             text = colorString(QString::number(fid), 31);
-            text += QLatin1String(" ");
+            text += " ";
             text += colorString(file.url(), 32);
             stream << text << endl;
         }
@@ -124,7 +121,7 @@ int main(int argc, char* argv[])
             stream << "\t" << "Rating: " << file.rating() << endl;
 
         if (!file.tags().isEmpty())
-            stream << "\t" << "Tags: " << file.tags().join(QLatin1String(", ")) << endl;
+            stream << "\t" << "Tags: " << file.tags().join(", ") << endl;
 
         if (!file.userComment().isEmpty())
             stream << "\t" << "User Comment: " << file.userComment() << endl;
