@@ -17,21 +17,19 @@
  *
  */
 
-#include "config.h"
+//#include "config.h"
 
 #include "xapiandatabase.h"
 #include "xapiandocument.h"
 
-#include <KDebug>
+#include <QDebug>
 #include <QTimer>
 #include <QDir>
 
 #if defined(HAVE_MALLOC_H)
 #include <malloc.h>
-#include <unistd.h>
-#else
-#include <unistd.h>
 #endif
+#include <unistd.h>
 
 using namespace Baloo;
 
@@ -48,8 +46,8 @@ XapianDatabase::XapianDatabase(const QString& path, bool writeOnly)
             m_db = new Xapian::Database(m_path);
         }
         catch (const Xapian::DatabaseError& err) {
-            kError() << "Serious Error: " << err.get_error_string();
-            kError() << err.get_msg().c_str() << err.get_context().c_str() << err.get_description().c_str();
+            qWarning() << "Serious Error: " << err.get_error_string();
+            qWarning() << err.get_msg().c_str() << err.get_context().c_str() << err.get_description().c_str();
         }
 
         // Possible errors - DatabaseLock error
@@ -60,11 +58,6 @@ XapianDatabase::XapianDatabase(const QString& path, bool writeOnly)
     }
 }
 
-XapianDatabase::~XapianDatabase()
-{
-    delete m_db;
-}
-
 void XapianDatabase::replaceDocument(uint id, const XapianDocument& doc)
 {
     replaceDocument(id, doc.doc());
@@ -103,7 +96,7 @@ void XapianDatabase::commit()
             m_wDb.commit();
         }
         catch (const Xapian::Error& err) {
-            kError() << err.get_error_string();
+            qWarning() << err.get_error_string();
         }
         return;
     }
@@ -114,7 +107,7 @@ void XapianDatabase::commit()
 
     Xapian::WritableDatabase wdb = createWritableDb();
 
-    kDebug() << "Adding:" << m_docsToAdd.size() << "docs";
+    qDebug() << "Adding:" << m_docsToAdd.size() << "docs";
     Q_FOREACH (const DocIdPair& doc, m_docsToAdd) {
         try {
             wdb.replace_document(doc.first, doc.second);
@@ -123,7 +116,7 @@ void XapianDatabase::commit()
         }
     }
 
-    kDebug() << "Removing:" << m_docsToRemove.size() << "docs";
+    qDebug() << "Removing:" << m_docsToRemove.size() << "docs";
     Q_FOREACH (Xapian::docid id, m_docsToRemove) {
         try {
             wdb.delete_document(id);
@@ -137,9 +130,9 @@ void XapianDatabase::commit()
         m_db->reopen();
     }
     catch (const Xapian::Error& err) {
-        kError() << err.get_error_string();
+        qWarning() << err.get_error_string();
     }
-    kDebug() << "Xapian Committed";
+    qDebug() << "Xapian Committed";
 
     m_docsToAdd.clear();
     m_docsToRemove.clear();
@@ -173,7 +166,7 @@ Xapian::WritableDatabase XapianDatabase::createWritableDb()
 {
     // We need to keep sleeping for a required amount, until we reach
     // a threshold. That's when we decide to abort?
-    for (int i = 1; i <= 20; ++i) {
+    for (int i = 1; i <= 20; i++) {
         try {
             Xapian::WritableDatabase wdb(m_path, Xapian::DB_CREATE_OR_OPEN);
             return wdb;
@@ -185,25 +178,21 @@ Xapian::WritableDatabase XapianDatabase::createWritableDb()
             usleep(i * 50 * 1000);
         }
         catch (const Xapian::DatabaseCreateError& err) {
-            kDebug() << err.get_error_string();
+            qDebug() << err.get_error_string();
             return Xapian::WritableDatabase();
         }
         catch (const Xapian::DatabaseCorruptError& err) {
-            kError() << "Database Corrupted - What did you do?";
-            kError() << err.get_error_string();
-            return Xapian::WritableDatabase();
-        }
-        catch (const std::exception& err) {
-            kError() << "Unknown exception: " << err.what();
+            qWarning() << "Database Corrupted - What did you do?";
+            qWarning() << err.get_error_string();
             return Xapian::WritableDatabase();
         }
         catch (...) {
-            kError() << "Bananana Error";
+            qWarning() << "Bananana Error";
             return Xapian::WritableDatabase();
         }
     }
 
-    kError() << "Could not obtain lock for Xapian Database. This is bad";
+    qWarning() << "Could not obtain lock for Xapian Database. This is bad";
     return Xapian::WritableDatabase();
 }
 
