@@ -27,7 +27,7 @@
 #include <QVector>
 #include <QStringList>
 #include <QTime>
-#include <KDebug>
+#include <QDebug>
 
 #include <algorithm>
 
@@ -35,8 +35,8 @@ using namespace Baloo;
 
 XapianSearchStore::XapianSearchStore(QObject* parent)
     : SearchStore(parent)
-    , m_mutex(QMutex::Recursive)
     , m_nextId(1)
+    , m_mutex(QMutex::Recursive)
     , m_db(0)
 {
 }
@@ -52,13 +52,13 @@ void XapianSearchStore::setDbPath(const QString& path)
         m_db = new Xapian::Database(m_dbPath.toUtf8().constData());
     }
     catch (const Xapian::DatabaseOpeningError&) {
-        kError() << "Xapian Database does not exist at " << m_dbPath;
+        qWarning() << "Xapian Database does not exist at " << m_dbPath;
     }
     catch (const Xapian::DatabaseCorruptError&) {
-        kError() << "Xapian Database corrupted at " << m_dbPath;
+        qWarning() << "Xapian Database corrupted at " << m_dbPath;
     }
     catch (...) {
-        kError() << "Random exception, but we do not want to crash";
+        qWarning() << "Random exception, but we do not want to crash";
     }
 }
 
@@ -139,7 +139,7 @@ namespace {
         const std::string stdString(string.toLower().toUtf8().constData());
         Xapian::TermIterator it = db->allterms_begin(stdString);
         Xapian::TermIterator end = db->allterms_end(stdString);
-        for (; it != end; ++it) {
+        for (; it != end; it++) {
             Term term;
             term.t = *it;
             term.count = db->get_collection_freq(term.t);
@@ -174,7 +174,7 @@ namespace {
 Xapian::Query XapianSearchStore::constructSearchQuery(const QString& str)
 {
     QVector<Xapian::Query> queries;
-    QRegExp splitRegex(QLatin1String("[\\s.+*/\\-=]"));
+    QRegExp splitRegex("[\\s.]");
     QStringList list = str.split(splitRegex, QString::SkipEmptyParts);
 
     QMutableListIterator<QString> iter(list);
@@ -187,7 +187,7 @@ Xapian::Query XapianSearchStore::constructSearchQuery(const QString& str)
     }
 
     if (!list.isEmpty()) {
-        std::string stdStr(list.join(QLatin1String(" ")).toUtf8().constData());
+        std::string stdStr(list.join(" ").toUtf8().constData());
 
         Xapian::QueryParser parser;
         parser.set_database(*m_db);
@@ -211,7 +211,7 @@ int XapianSearchStore::exec(const Query& query)
             try {
                 m_db->reopen();
             } catch (Xapian::DatabaseError& e) {
-                kWarning() << "Failed to reopen database" << dbPath() << ":" <<  QString::fromStdString(e.get_msg());
+                qDebug() << "Failed to reopen database" << dbPath() << ":" <<  QString::fromStdString(e.get_msg());
                 return 0;
             }
 
@@ -239,9 +239,6 @@ int XapianSearchStore::exec(const Query& query)
         catch (const Xapian::DatabaseModifiedError&) {
             continue;
         }
-        catch (const Xapian::Error&) {
-            return 0;
-        }
     }
 
     return 0;
@@ -297,7 +294,7 @@ bool XapianSearchStore::next(int queryId)
     else {
         res.lastId = *res.it;
         res.lastUrl.clear();
-        ++res.it;
+        res.it++;
     }
 
     return !atEnd;
@@ -324,9 +321,6 @@ Xapian::Document XapianSearchStore::docForQuery(int queryId)
         m_db->reopen();
         return docForQuery(queryId);
     }
-    catch (const Xapian::Error&) {
-        return Xapian::Document();
-    }
 }
 
 Xapian::Database* XapianSearchStore::xapianDb()
@@ -347,7 +341,7 @@ Xapian::Query XapianSearchStore::finalizeQuery(const Xapian::Query& query)
     return query;
 }
 
-Xapian::Query XapianSearchStore::applyCustomOptions(const Xapian::Query& q, const QVariantHash& options)
+Xapian::Query XapianSearchStore::applyCustomOptions(const Xapian::Query& q, const QVariantMap& options)
 {
     Q_UNUSED(options);
     return q;
