@@ -71,7 +71,7 @@ protected:
     /**
      * Create a query for any custom options.
      */
-    virtual Xapian::Query applyCustomOptions(const Xapian::Query& q, const QVariantHash& options);
+    virtual Xapian::Query applyCustomOptions(const Xapian::Query& q, const QVariantMap& options);
 
     /**
      * Returns the url for the document with id \p docid.
@@ -100,9 +100,6 @@ protected:
 
     Xapian::Database* xapianDb();
 
-protected:
-    QMutex m_mutex;
-
 private:
     Xapian::Query toXapianQuery(const Term& term);
     Xapian::Query toXapianQuery(Xapian::Query::op op, const QList<Term>& terms);
@@ -121,6 +118,7 @@ private:
     int m_nextId;
 
     QString m_dbPath;
+    QMutex m_mutex;
 
     Xapian::Database* m_db;
 };
